@@ -307,7 +307,9 @@ class VirtualService(BaseKempObject):
 
         # Clear the persist timeout if persistence is not used
         if hasattr(self, "persist") and self.persist is None:
-            self.persisttimeout = None
+            # Setting persisttimeout=0 via the API
+            # also clears the persist field on the service
+            self.persisttimeout = 0
 
         if self.subvs_entries:
             self.enhancedhealthchecks = None
